@@ -1,10 +1,9 @@
 from dataclasses import asdict
-from common.views import RESTResponse
 from django.http import HttpResponse, JsonResponse
 from django.utils.deprecation import MiddlewareMixin
 import json
 from common.logging_config import get_my_logger, DOCUMENTPATH
-from common.response_param import Results, REQUEST_ERROR_CODE, FORBID_CODE, UNAUTHORIZED
+from common.rest_extend.response import Results, REQUEST_ERROR_CODE, FORBID_CODE, UNAUTHORIZED
 
 logger = get_my_logger(DOCUMENTPATH, "django")
 
@@ -28,8 +27,8 @@ def record_log(request, response=None):
         body = json.dumps(json.loads(request.body)) if request.body else ""
     except Exception as e:
         logger.exception(e)
-        # body = request.body
-        return True
+        body = request.body
+        # return True
     if response:
         try:
             content = json.dumps(json.loads(response.content))
